Learn R Programming

satellite (version 0.1.0)

satInfo: Get or access Satellite object information used by various functions

Description

Get information from class Satellite.

Usage

getSatDataLayers(sat, bcde = NULL)

getSatDataLayer(sat, bcde)

getSatMeta(sat, bcde)

getSatMetaBCDETemplate(sat, bcde)

getSatLog(sat)

setSatBCDE(sat, bcde)

createSatBCDE(sat, width = 3, flag = 0, prefix = "B", postfix = "n")

addSatMetaParam(sat, meta_param)

addSatMetaEntry(sat, meta_param)

addSatLog(sat, info = NA_character_, in_bcde = NA_character_, out_bcde = NA_character_)

addSatDataLayer(sat, bcde, data, meta_param, info, in_bcde)

addRasterMeta2Sat(sat)

createRasterMetaData(rst)

updateRasterMetaData(sat, bcde)

countSatDataLayers(sat)

getSatParam(sat, param, bcde, return_bcde = TRUE)

getSatBCDE(sat, lnbr)

getSatBID(sat, bcde)

getSatSID(sat)

getSatSensor(sat)

getSatSensorGroup(sat)

getSatSensorInfo(sat)

getSatSpectrum(sat, bcde)

getSatBCDESolar(sat)

getSatBCDEThermal(sat)

getSatXRes(sat, bcde)

getSatYRes(sat, bcde)

getSatRes(sat, bcde)

getSatType(sat, bcde)

getSatCalib(sat, bcde)

getSatBCDEType(sat, bcde, type)

getSatBCDEFromType(sat, type = "VIS")

getSatBCDEFromSpectrum(sat, spectrum = "solar")

getSatBCDESres(sat, bcde, type)

getSatBCDECalib(sat, bcde, calib)

getSatBCDESolarCalib(sat, bcde, calib)

getSatBCDEThermalCalib(sat, bcde, calib)

getSatBandInfo(sat, bcde, return_calib = TRUE)

getSatRadMax(sat, bcde)

getSatRadMin(sat, bcde)

getSatRefMax(sat, bcde)

getSatRefMin(sat, bcde)

getSatESD(sat)

getSatESUN(sat, bcde)

getSatSZEN(sat, bcde)

getSatSAZM(sat, bcde)

getSatSELV(sat, bcde)

getSatMetaLayer(sat, bcde)

getSatLayerfromData(sat, bcde, nbr)

getSatLNBR(sat, bcde)

getSatLMIN(sat, bcde)

getSatLMAX(sat, bcde)

getSatRADA(sat, bcde)

getSatRADM(sat, bcde)

getSatREFA(sat, bcde)

getSatREFM(sat, bcde)

getSatBTK1(sat, bcde)

getSatBTK2(sat, bcde)

getSatPRAD(sat, bcde)

getSatDATE(sat, bcde)

getSatProjection(sat, bcde)

Arguments

sat
Satellite object (see satellite).
bcde
Band code.
width,flag
Field width and format modifier for automated creation of BCDE information, defaults to '3' and '0', respectively. See formatC for further details.
prefix,postfix
Prefix and postfix to be added to the created BCDE information.
meta_param
Metadata parameters used to document new data layer
info
Log information added to metadata
in_bcde
BCDE of layer used as input dataset
out_bcde
BCDE of layer used as output dataset
data
Data layer of a satellite object
rst
Input raster::Raster* object from which to extract metadata.
param
Parameter of the metadata set (i.e. colname)
return_bcde
Return bcde as attribute (TRUE/FALSE)
lnbr
Layer number
type
Type of the sensor band
spectrum
Spectral region, e.g. "solar" or "thermal".
calib
Calibration information.
return_calib
Return calibration information (TRUE/FALSE)
nbr
Return specific data layer selected by number

Value

Functions

  • getSatDataLayers: Return Satellite data layers
  • getSatDataLayer: Return Satellite data layer i
  • getSatMeta: Return Satellite object metadata
  • getSatMetaBCDETemplate: Return template for Satellite object metadata which is based on existing band
  • getSatLog: Return Satellite object log info
  • setSatBCDE: Set BCDE/data layer names of a Satellite object
  • createSatBCDE: If not supplied, automatically create BCDE names of a Satellite object
  • addSatMetaParam: Add additional or overwrite metainformation parameter to Satellite object
  • addSatMetaEntry: Add metainformation for an additional layer to Satellite object
  • addSatLog: Add new log entry to Satellite object
  • addSatDataLayer: Add new Satellite data layer
  • addRasterMeta2Sat: Add raster meta data to Satellite object meta data
  • createRasterMetaData: Create raster meta data
  • updateRasterMetaData: Create raster meta data
  • countSatDataLayers: Return number of Satellite data layers
  • getSatParam: Return parameter (general method implemented by the specific functions below)
  • getSatBCDE: Return Band code
  • getSatBID: Return Band IDs
  • getSatSID: Return sensor ID
  • getSatSensor: Return sensor
  • getSatSensorGroup: Return sensor group
  • getSatSensorInfo: Return sensor information
  • getSatSpectrum: Return spectrum
  • getSatBCDESolar: Return solar band codes
  • getSatBCDEThermal: Return thermal band codes
  • getSatXRes: Return sensor x resolution
  • getSatYRes: Return sensor y resolution
  • getSatRes: Return mean sensor resolution (mean of x and y res)
  • getSatType: Return sensor type
  • getSatCalib: Return calibration level
  • getSatBCDEType: Return TYPE band codes
  • getSatBCDEFromType: Return BCDE matching TYPE
  • getSatBCDEFromSpectrum: Return BCDE matching TYPE
  • getSatBCDESres: Return the mean of x and y resolution for band codes matching type
  • getSatBCDECalib: Return calibration level for band codes matching type
  • getSatBCDESolarCalib: Return calibration level for band codes machting type and are solar bands
  • getSatBCDEThermalCalib: Return calibration level for band codes machting type and are thermal bands
  • getSatBandInfo: Return band information
  • getSatRadMax: Return maximum radiance for bcde
  • getSatRadMin: Return minimum radiance for bcde
  • getSatRefMax: Return maximum reflectance for bcde
  • getSatRefMin: Return minimum reflectance for bcde
  • getSatESD: Return earth-sun distance
  • getSatESUN: Return actual solar TOA irradiance
  • getSatSZEN: Return sun zenith angle
  • getSatSAZM: Return sun azimuth angle
  • getSatSELV: Return Sun elevation
  • getSatMetaLayer: Return Layer name from metadata
  • getSatLayerfromData: Return Layer name from data layer
  • getSatLNBR: Return Layer number
  • getSatLMIN: Return minimum wavelength of the sensor band
  • getSatLMAX: Return maximum wavelength of the sensor band
  • getSatRADA: Return addition coefficient for SC to radiance conversion
  • getSatRADM: Return multiplicative coefficient for SC to radiance conversion
  • getSatREFA: Return addition coefficient for SC to reflectance
  • getSatREFM: Return multiplicative coefficient for SC to reflectance
  • getSatBTK1: Return calibration coefficent to convert SC to brightness temperature
  • getSatBTK2: Return calibration coefficent to convert SC to brightness temperature
  • getSatDATE: Return DATE
  • getSatProjection: Return projection

Details

The functions are generally self-explaining in that sence that get* returns the respective information and set* sets the respective information from/in the Satellite object.

addSatLog adds a log entry to the Satellite object.

Examples

Run this code
# List of input files
path <- system.file("extdata", package = "satellite")
files <- list.files(path, pattern = glob2rx("LC8*.tif"), full.names = TRUE)
sat <- satellite(files)

# Raster stack l8
sat <- satellite(l8)

Run the code above in your browser using DataLab