Usage
## S3 method for class 'Satellite':
calcHistMatch(x, target, bcde = NULL, minv = 0L,
maxv = 1023L, use_cpp = TRUE)## S3 method for class 'RasterStack':
calcHistMatch(x, target, minv = 0L, maxv = 1023L,
use_cpp = TRUE)
## S3 method for class 'RasterLayer':
calcHistMatch(x, target, minv = 0L, maxv = 1023L,
use_cpp = TRUE)
Arguments
x
Satellite or raster::Raster* object providing the source band(s) to
be adjusted.
target
The target band as raster::RasterLayer.
bcde
Band code which should be alligned
minv
Lower limit of the possible range for transformation (if not
provided, defaults to the minimum of both layers).
maxv
Upper limit of the possible range for transformation (if not
provided, defaults to the maximum of both layers).
use_cpp
Logical. If TRUE, C++ functionality (via Rcpp)
is enabled, which leads to a considerable reduction of both computation time
and memory usage.