getSatDataLayers(sat, bcde = NULL)getSatDataLayer(sat, bcde)
getSatMeta(sat, bcde)
getSatMetaBCDETemplate(sat, bcde)
getSatLog(sat)
setSatBCDE(sat, bcde)
createSatBCDE(sat, width = 3, flag = 0, prefix = "B", postfix = "n")
addSatMetaParam(sat, meta_param)
addSatMetaEntry(sat, meta_param)
addSatLog(sat, info = NA_character_, in_bcde = NA_character_,
out_bcde = NA_character_)
addSatDataLayer(sat, bcde, data, meta_param, info, in_bcde)
addRasterMeta2Sat(sat)
createRasterMetaData(rst)
updateRasterMetaData(sat, bcde)
countSatDataLayers(sat)
getSatParam(sat, param, bcde, return_bcde = TRUE)
getSatBCDE(sat, lnbr)
getSatBID(sat, bcde)
getSatSID(sat)
getSatSensor(sat)
getSatSensorGroup(sat)
getSatSensorInfo(sat)
getSatSpectrum(sat, bcde)
getSatBCDESolar(sat)
getSatBCDEThermal(sat)
getSatXRes(sat, bcde)
getSatYRes(sat, bcde)
getSatRes(sat, bcde)
getSatType(sat, bcde)
getSatCalib(sat, bcde)
getSatBCDEType(sat, bcde, type)
getSatBCDEFromType(sat, type = "VIS")
getSatBCDEFromSpectrum(sat, spectrum = "solar")
getSatBCDESres(sat, bcde, type)
getSatBCDECalib(sat, bcde, calib)
getSatBCDESolarCalib(sat, bcde, calib)
getSatBCDEThermalCalib(sat, bcde, calib)
getSatBandInfo(sat, bcde, return_calib = TRUE)
getSatRadMax(sat, bcde)
getSatRadMin(sat, bcde)
getSatRefMax(sat, bcde)
getSatRefMin(sat, bcde)
getSatESD(sat)
getSatESUN(sat, bcde)
getSatSZEN(sat, bcde)
getSatSAZM(sat, bcde)
getSatSELV(sat, bcde)
getSatMetaLayer(sat, bcde)
getSatLayerfromData(sat, bcde, nbr)
getSatLNBR(sat, bcde)
getSatLMIN(sat, bcde)
getSatLMAX(sat, bcde)
getSatRADA(sat, bcde)
getSatRADM(sat, bcde)
getSatREFA(sat, bcde)
getSatREFM(sat, bcde)
getSatBTK1(sat, bcde)
getSatBTK2(sat, bcde)
getSatPRAD(sat, bcde)
getSatDATE(sat, bcde)
getSatProjection(sat, bcde)
satellite).formatC for further details.satellite).getSatDataLayers: Return Satellite data layersgetSatDataLayer: Return Satellite data layer igetSatMeta: Return Satellite object metadatagetSatMetaBCDETemplate: Return template for Satellite object metadata which is based on existing bandgetSatLog: Return Satellite object log infosetSatBCDE: Set BCDE/data layer names of a Satellite objectcreateSatBCDE: If not supplied, automatically create BCDE names of a Satellite objectaddSatMetaParam: Add additional or overwrite metainformation parameter to Satellite objectaddSatMetaEntry: Add metainformation for an additional layer to Satellite objectaddSatLog: Add new log entry to Satellite objectaddSatDataLayer: Add new Satellite data layeraddRasterMeta2Sat: Add raster meta data to Satellite object meta datacreateRasterMetaData: Create raster meta dataupdateRasterMetaData: Create raster meta datacountSatDataLayers: Return number of Satellite data layersgetSatParam: Return parameter (general method implemented by the specific functions below)getSatBCDE: Return Band codegetSatBID: Return Band IDsgetSatSID: Return sensor IDgetSatSensor: Return sensorgetSatSensorGroup: Return sensor groupgetSatSensorInfo: Return sensor informationgetSatSpectrum: Return spectrumgetSatBCDESolar: Return solar band codesgetSatBCDEThermal: Return thermal band codesgetSatXRes: Return sensor x resolutiongetSatYRes: Return sensor y resolutiongetSatRes: Return mean sensor resolution (mean of x and y res)getSatType: Return sensor typegetSatCalib: Return calibration levelgetSatBCDEType: Return TYPE band codesgetSatBCDEFromType: Return BCDE matching TYPEgetSatBCDEFromSpectrum: Return BCDE matching TYPEgetSatBCDESres: Return the mean of x and y resolution for band codes matching typegetSatBCDECalib: Return calibration level for band codes matching typegetSatBCDESolarCalib: Return calibration level for band codes machting type and are solar bandsgetSatBCDEThermalCalib: Return calibration level for band codes machting type and are thermal bandsgetSatBandInfo: Return band informationgetSatRadMax: Return maximum radiance for bcdegetSatRadMin: Return minimum radiance for bcdegetSatRefMax: Return maximum reflectance for bcdegetSatRefMin: Return minimum reflectance for bcdegetSatESD: Return earth-sun distancegetSatESUN: Return actual solar TOA irradiancegetSatSZEN: Return sun zenith anglegetSatSAZM: Return sun azimuth anglegetSatSELV: Return Sun elevationgetSatMetaLayer: Return Layer name from metadatagetSatLayerfromData: Return Layer name from data layergetSatLNBR: Return Layer numbergetSatLMIN: Return minimum wavelength of the sensor bandgetSatLMAX: Return maximum wavelength of the sensor bandgetSatRADA: Return addition coefficient for SC to radiance conversiongetSatRADM: Return multiplicative coefficient for SC to radiance conversiongetSatREFA: Return addition coefficient for SC to reflectancegetSatREFM: Return multiplicative coefficient for SC to reflectancegetSatBTK1: Return calibration coefficent to convert SC to brightness temperaturegetSatBTK2: Return calibration coefficent to convert SC to brightness temperaturegetSatDATE: Return DATEgetSatProjection: Return projectionget* returns the respective information and set* sets the
respective information from/in the Satellite object.addSatLog adds a log entry to the Satellite object.
# List of input files
path <- system.file("extdata", package = "satellite")
files <- list.files(path, pattern = glob2rx("LC8*.tif"), full.names = TRUE)
sat <- satellite(files)
# Raster stack l8
sat <- satellite(l8)Run the code above in your browser using DataLab